@@ -34,17 +34,16 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import print_function
 
 import os
 from glob import glob
 from subprocess import call
 from time import sleep
+from urllib.parse import urlparse
 
 from defusedxml import ElementTree, lxml
 from saml2 import BINDING_SOAP
 from saml2.md import NAMESPACE
-from six.moves.urllib_parse import urlparse
 
 
 workaround = set()
@@ -145,7 +144,7 @@ def rewrite_sasl_configuration():
 def reload_webserver():
     try:
         call(['systemctl', 'reload', 'univention-management-console-server'])
-    except (IOError, OSError):
+    except OSError:
         pass
 
 
