@@ -65,18 +65,15 @@ used
     udm/* !objectType
 """
 
-from __future__ import absolute_import
 
 import itertools
 import json
 import operator
 import os
-import pickle  # noqa: S403
 import traceback
 from fnmatch import fnmatch
 
 import ldap
-import six
 from ldap.filter import filter_format
 
 import univention.admin.handlers.computers.domaincontroller_backup as dc_backup
@@ -224,7 +221,7 @@ class ACLs(object):
             if key not in opts:
                 continue
 
-            if isinstance(opts[key], six.string_types):
+            if isinstance(opts[key], str):
                 options = (opts[key], )
             else:
                 options = opts[key]
@@ -314,17 +311,10 @@ class ACLs(object):
         filename = os.path.join(ACLs.CACHE_DIR, username.replace('/', ''))
 
         try:
-            try:
-                with open(filename) as fd:
-                    acls = json.load(fd)
-            except (ValueError, TypeError):
-                if six.PY3:
-                    raise
-                with open(filename) as fd:
-                    acls = pickle.load(fd)  # noqa: S301
-            else:
-                acls = [Rule(x) for x in acls]
-        except EnvironmentError as exc:
+            with open(filename) as fd:
+                acls = json.load(fd)
+            acls = [Rule(x) for x in acls]
+        except OSError as exc:
             ACL.process('Could not load ACLs of %r: %s' % (username, exc))
             return False
 
@@ -344,7 +334,7 @@ class ACLs(object):
             file = os.open(filename, os.O_WRONLY | os.O_TRUNC | os.O_CREAT, 0o600)
             os.write(file, json.dumps(self.acls, ensure_ascii=True).encode('ASCII'))
             os.close(file)
-        except EnvironmentError as exc:
+        except OSError as exc:
             ACL.error('Could not write ACL file: %s' % (exc,))
             return False
 
