@@ -49,7 +49,6 @@ Example usage::
 
 """
 
-from __future__ import absolute_import
 
 import functools
 from errno import ENOENT
@@ -99,7 +98,7 @@ class LDAP(object):
         def connection():
             try:
                 return _getMachineConnection(**kwargs)
-            except IOError as exc:
+            except OSError as exc:
                 if exc.errno == ENOENT:
                     return  # /etc/machine.secret does not exists
                 raise
@@ -111,7 +110,7 @@ class LDAP(object):
         def connection():
             try:
                 return _getAdminConnection(**kwargs)
-            except IOError as exc:
+            except OSError as exc:
                 if exc.errno == ENOENT:
                     return  # /etc/ldap.secret does not exists
                 raise
