@@ -37,16 +37,15 @@
 A backwards compatible layer to wrap HTTP request and response messages.
 The API of the Python objects representing the messages are based on the class :class:`.Message`.
 """
-from __future__ import absolute_import, print_function
 
 import mimetypes
 import sys
 import time
 import weakref
+from typing import Any, Dict, List, Optional, Union  # noqa: F401
 
 import ldap
 import ldap.sasl
-import six
 
 import univention.admin.uexceptions as udm_errors
 from univention.management.console.error import PasswordRequired
@@ -54,12 +53,8 @@ from univention.management.console.ldap import get_user_connection
 from univention.management.console.log import CORE, PARSER, PROTOCOL
 
 
-try:
-    from typing import Any, Dict, List, Optional, Text, Union  # noqa: F401
-    RequestType = int
-    UmcpBody = Union[dict, str, bytes]
-except ImportError:
-    pass
+RequestType = int
+UmcpBody = Union[dict, str, bytes]
 
 MIMETYPE_JSON = 'application/json'
 
@@ -95,8 +90,8 @@ class Message(object):
     __counter = 0
 
     def __init__(self, type=REQUEST, command=u'', mime_type=MIMETYPE_JSON, data=None, arguments=None, options=None):
-        # type: (RequestType, Text, str, bytes, List[str], Dict[str, Any]) -> None
-        self.id = None  # type: Optional[Text]
+        # type: (RequestType, str, str, bytes, List[str], Dict[str, Any]) -> None
+        self.id = None  # type: Optional[str]
         if mime_type == MIMETYPE_JSON:
             self.body = {}  # type: UmcpBody
         else:
@@ -228,13 +223,13 @@ class Request(Message):
                         lo.lo.bind_saml(self.password)
                     except ldap.OTHER:
                         CORE.error('SAML authentication failed.')
-                        six.reraise(etype, exc, etraceback)
+                        raise exc.with_traceback(etraceback)
                     CORE.error('Wrong authentication type. Resetting.')
                     self.auth_type = 'SAML'
         except ldap.INVALID_CREDENTIALS:
             etype, exc, etraceback = sys.exc_info()
             exc = etype('An error during LDAP authentication happened. Auth type: %s; SAML message length: %s; DN length: %s; Original Error: %s' % (self.auth_type, len(self.password or '') if len(self.password or '') > 25 else False, len(self.user_dn or ''), exc))
-            six.reraise(etype, exc, etraceback)
+            raise exc.with_traceback(etraceback)
 
 
 class Response(Message):
