@@ -43,10 +43,8 @@ import re
 import signal
 import sys
 import tempfile
-import threading
 import traceback
 
-import six
 import tornado.httputil
 import tornado.locale
 from tornado.httpserver import HTTPServer
@@ -140,28 +138,13 @@ class ModuleServer(object):
         signal.signal(signal.SIGHUP, self.signal_handler_reload)
         signal.signal(signal.SIGUSR1, self.signal_handler_reload)
 
-        import notifier.nf_tornado
-        notifier.nf_tornado.replace_threads()
-
         # TODO: remove in UCS 5.1:
-        # we don't need to start a second loop if we use the tornado main loop
-        self.nf_thread = None
-        self.running = True
-        if notifier.loop is not getattr(getattr(notifier, 'nf_tornado', None), 'loop', None):
-            def loop():
-                while self.running:
-                    notifier.step()
-            self.nf_thread = threading.Thread(target=loop, name='notifier')
-            self.nf_thread.start()
+        # allow other threads which are not created by asyncio to start the asyncio loop
+        # this is important for UMC modules which call finish() in the thread instead of the main thread!
+        import asyncio
 
-        if not six.PY2:
-            # TODO: remove in UCS 5.1:
-            # allow other threads which are not created by asyncio to start the asyncio loop
-            # this is important for UMC modules which call finish() in the thread instead of the main thread!
-            import asyncio
-
-            from tornado.platform.asyncio import AnyThreadEventLoopPolicy
-            asyncio.set_event_loop_policy(AnyThreadEventLoopPolicy())
+        from tornado.platform.asyncio import AnyThreadEventLoopPolicy
+        asyncio.set_event_loop_policy(AnyThreadEventLoopPolicy())
 
         server = HTTPServer(
             application,
@@ -176,8 +159,6 @@ class ModuleServer(object):
     def __exit__(self, etype, exc, etraceback):
         self.running = False
         self.ioloop.stop()
-        if self.nf_thread:
-            self.nf_thread.join()
 
     def loop(self):
         self.ioloop = tornado.ioloop.IOLoop.current()
@@ -323,8 +304,7 @@ class Handler(RequestHandler):
         if self.handler:
             self.handler._Base__requests.pop(self.request_id, None)
 
-    @tornado.web.asynchronous
-    def get(self, path):
+    async def get(self, path):
         try:
             username, password = self.parse_authorization()
         except TypeError:  # can only happen when doing manual requests
@@ -378,10 +358,7 @@ class Handler(RequestHandler):
 
         msg.headers = dict(self.request.headers)
         msg.http_method = self.request.method
-        if six.PY2:
-            msg.cookies = {x.key.decode('ISO8859-1'): x.value.decode('ISO8859-1') for x in self.request.cookies.values()}
-        else:
-            msg.cookies = {x.key: x.value for x in self.request.cookies.values()}
+        msg.cookies = {x.key: x.value for x in self.request.cookies.values()}
         for name, value in list(msg.cookies.items()):
             if name == self.suffixed_cookie_name('UMCSessionId'):
                 msg.cookies['UMCSessionId'] = value
@@ -412,8 +389,6 @@ class Handler(RequestHandler):
             for key, val in response.headers.items():
                 self.set_header(key, val)
         for key, item in response.cookies.items():
-            if six.PY2 and not isinstance(key, bytes):
-                key = key.encode('utf-8')  # bug in python Cookie!
             if not isinstance(item, dict):
                 item = {'value': item}
             self.set_cookie(key, **item)
