@@ -49,7 +49,7 @@ The following example defines a module with the id `udm`:
 
     <?xml version="1.0" encoding="UTF-8"?>
     <umc version="2.0">
-        <module id="udm" icon="udm-module" version="1.0" python="3">
+        <module id="udm" icon="udm-module" version="1.0">
             <name>Univention Directory Manager</name>
             <description>Manages all UDM modules</description>
             <flavor icon="udm-users" id="users/user">
@@ -124,7 +124,7 @@ import copy
 import os
 import re
 import sys
-import xml.etree.cElementTree as ET  # noqa: S405
+import xml.etree.ElementTree as ET  # noqa: S405
 import xml.parsers.expat
 
 from .config import ucr
@@ -323,17 +323,6 @@ class XML_Definition(ET.ElementTree):
     def translationId(self):
         return self.root.get('translationId', '')
 
-    @property
-    def notifier(self):
-        return self.root.get('notifier')
-
-    @property
-    def python_version(self):
-        try:
-            return int(float(self.root.get('python', 2)))
-        except ValueError:
-            return 2
-
     @property
     def singleton(self):
         return self.root.get('singleton', 'no').lower() in ('yes', 'true', '1')
@@ -451,7 +440,7 @@ class Manager(dict):
             if not filename.endswith('.xml'):
                 continue
             try:
-                parsed_xml = ET.parse(os.path.join(Manager.DIRECTORY, filename))  # noqa: S313
+                parsed_xml = ET.parse(os.path.join(Manager.DIRECTORY, filename))  # noqa: S313, S314
                 RESOURCES.debug('Loaded module %s' % filename)
                 for mod_tree in parsed_xml.getroot():
                     mod = XML_Definition(root=mod_tree)
