@@ -635,8 +635,7 @@ class RequestOptionsIterator(object):
 
 
 def arginspect(function):
-    getfullargspec = getattr(inspect, 'getfullargspec', getattr(inspect, 'getargspec', None))
-    argspec = getfullargspec(function)
+    argspec = inspect.getfullargspec(function)
     if hasattr(function, '_original_argument_names'):
         arguments = function._original_argument_names
     else:
