@@ -52,7 +52,6 @@ import copy
 import re
 
 import ldap.filter
-import six
 
 from univention.lib.i18n import Translation
 
@@ -558,7 +557,7 @@ class PatternSanitizer(SearchSanitizer):
     def __init__(self, ignore_case=True, multiline=True, **kwargs):
         # type: (bool, bool, **Any) -> None
         default = kwargs.get('default')
-        if isinstance(default, six.string_types):
+        if isinstance(default, str):
             default = re.compile(default)
         kwargs['default'] = default
         super(PatternSanitizer, self).__init__(**kwargs)
@@ -606,13 +605,13 @@ class StringSanitizer(Sanitizer):
             is a string
     :param int minimum: the minimum length of the string
     :param int maximum: the maximum length of the string
-    :type regex_pattern: six.string_types or re._pattern_type
+    :type regex_pattern: str or re._pattern_type
     """
 
     def __init__(self, regex_pattern=None, re_flags=0, minimum=None, maximum=None, **kwargs):
         # type: (Union[None, Pattern[str], str], int, Optional[int], Optional[int], **Any) -> None
         super(StringSanitizer, self).__init__(**kwargs)
-        if isinstance(regex_pattern, six.string_types):
+        if isinstance(regex_pattern, str):
             regex_pattern = re.compile(regex_pattern, flags=re_flags)
         self.minimum = minimum
         self.maximum = maximum
@@ -634,7 +633,7 @@ class StringSanitizer(Sanitizer):
 
     def _sanitize(self, value, name, further_args):
         # type: (Any, str, Mapping[str, object]) -> object
-        if not isinstance(value, six.string_types):
+        if not isinstance(value, str):
             self.raise_validation_error(_('Value is not a string'))
 
         if self.minimum and len(value) < self.minimum:
