@@ -38,10 +38,10 @@ import os
 import time
 import uuid
 from time import monotonic
+from urllib.parse import urlencode, urlparse, urlunsplit
 
 import jwt
 from jwt.algorithms import RSAAlgorithm
-from six.moves.urllib_parse import urlencode, urlparse, urlunsplit
 from sqlalchemy import exc
 from tornado import escape
 from tornado.auth import OAuth2Mixin
@@ -146,7 +146,7 @@ class OIDCResource(OAuth2Mixin, Resource):
                 code_verifier=code_verifier,
             )
         except HTTPClientError as exc:
-            CORE.error('Could not get access token: %s' % (exc.response and exc.response.body or exc,))
+            CORE.error('Could not get access token: %s' % (exc.response.body,))
             raise OpenIDProvideUnavailable(self._('Could not receive token from authorization server.'))
 
         try:
@@ -353,7 +353,7 @@ class OIDCResource(OAuth2Mixin, Resource):
             json_response = escape.json_decode(exc.response.body)
             if json_response.get('error') == 'invalid_grant':
                 if user.session_id in Session.sessions:
-                    Session.sessions[user.session_id].logout(reload=False)
+                    Session.sessions[user.session_id].logout()
             CORE.error('Could not get new access token: %s' % (json_response))
             raise OpenIDProvideUnavailable(self._('Could not receive token from authorization server.'))
 
@@ -467,7 +467,6 @@ class OIDCLogout(_OIDCLogoutBase):
         logout_url = '%s?%s' % (self._OAUTH_END_SESSION_URL, urlencode({
             'post_logout_redirect_uri': self.reverse_abs_url('oidc-logout-done'),
             'client_id': self.client_id,
-            'id_token_hint': user.oidc.id_token,
             # 'logout_hint': None,
             # 'ui_locales': None,
         }))
@@ -519,10 +518,7 @@ class OIDCFrontchannelLogout(_OIDCLogoutBase):
         self.add_header('Cache-Control', 'no-store')
         # self.get_query_argument('iss')
         # sid = self.get_query_argument('sid')
-        user = self.current_user
-        if user:
-            user.oidc = None
-        self.expire_session()
+        return self._logout_success()
 
 
 class OIDCBackchannelLogout(OIDCResource):
