@@ -35,6 +35,7 @@
 
 import re
 import traceback
+from typing import Any, Dict, Iterator, List, Optional, Pattern, Sequence, Tuple, Union  # noqa: F401
 
 from PAM import (
     PAM_ACCT_EXPIRED, PAM_AUTH_ERR, PAM_AUTHTOK_ERR, PAM_AUTHTOK_RECOVER_ERR, PAM_CONV, PAM_ERROR_MSG,
@@ -47,12 +48,6 @@ from univention.management.console.config import ucr
 from univention.management.console.log import AUTH
 
 
-try:
-    from typing import Any, Dict, Iterator, List, Optional, Pattern, Sequence, Text, Tuple, Union  # noqa: F401
-except ImportError:
-    pass
-
-
 _ = Translation('univention.management.console').translate
 
 _('The password is too short.')
@@ -351,7 +346,7 @@ class PamAuth(object):
         }
         return errors.get(pam_err[1], self._(str(pam_err[0])))
 
-    def _parse_password_change_fail_reason(self, prompt):  # type: (Union[Text, bytes]) -> str
+    def _parse_password_change_fail_reason(self, prompt):  # type: (Union[str, bytes]) -> str
         if prompt in self.known_errors:
             return self._(self.known_errors[prompt])
         for pattern, error_message in self.known_errors.items():
