@@ -37,10 +37,11 @@ import re
 import traceback
 import uuid
 import weakref
+from html import escape, unescape
+from http.client import LENGTH_REQUIRED, UNAUTHORIZED
 from http.server import BaseHTTPRequestHandler
 
 import tornado
-from six.moves.http_client import LENGTH_REQUIRED, UNAUTHORIZED
 from tornado.gen import convert_yielded
 from tornado.web import HTTPError, RequestHandler
 
@@ -52,20 +53,6 @@ from univention.management.console.log import CORE
 from univention.management.console.session import Session
 
 
-try:
-    from html import escape, unescape
-except ImportError:  # Python 2
-    import HTMLParser
-    html_parser = HTMLParser.HTMLParser()
-    unescape = html_parser.unescape
-    from cgi import escape
-
-# the SameSite cookie attribute is only available from Python 3.8
-from six.moves.http_cookies import Morsel
-
-
-Morsel._reserved['samesite'] = 'SameSite'
-
 LENGTH_REQUIRED, UNAUTHORIZED = int(LENGTH_REQUIRED), int(UNAUTHORIZED)
 
 traceback_pattern = re.compile(r'(Traceback.*most recent call|File.*line.*in.*\d)')
@@ -411,12 +398,12 @@ class Resource(RequestHandler):
             with open('/usr/share/univention-management-console-frontend/error.html') as fd:
                 content = fd.read().replace('%ERROR%', json.dumps(escape(content, True)))
             self.set_header('Content-Type', 'text/html; charset=UTF-8')
-        except (OSError, IOError):
+        except OSError:
             pass
         return content
 
     def default_error_page_json(self, status, message, stacktrace, result=None):
-        """The default error page for UMCP responses"""
+        """The default error page for responses"""
         if status == 401 and message == _http_response_codes.get(status):
             message = ''
         location = self.request.full_url().rsplit('/', 1)[0]
