@@ -39,8 +39,8 @@ Implements several helper classes to handle the state of a session
 and the communication with the module processes
 """
 
-# import asyncio.exceptions
 import asyncio
+import asyncio.exceptions
 import base64
 import errno
 import gzip
@@ -52,19 +52,19 @@ import stat
 import subprocess
 import time
 import uuid
+from http.client import LENGTH_REQUIRED, REQUEST_ENTITY_TOO_LARGE
 from ipaddress import ip_address
+from shlex import quote
+from time import monotonic
+from urllib.parse import urlparse, urlsplit, urlunsplit
 
-import concurrent.futures
 import ldap
 import pycurl
-import six
 import tornado
 import tornado.curl_httpclient
 import tornado.gen
 import tornado.httpclient
 import tornado.web
-from six.moves.http_client import LENGTH_REQUIRED, REQUEST_ENTITY_TOO_LARGE
-from six.moves.urllib_parse import urlparse, urlsplit, urlunsplit
 from tornado.iostream import StreamClosedError
 from tornado.web import HTTPError
 
@@ -85,17 +85,6 @@ from .session import categoryManager, moduleManager
 from .sse import logout_notifiers
 
 
-try:
-    from time import monotonic
-except ImportError:
-    from monotonic import monotonic
-
-try:
-    from shlex import quote
-except ImportError:
-    from pipes import quote
-
-
 def sanitize(*sargs, **skwargs):
     defaults = {'default': {}, 'required': True, 'may_change_value': True}
     if sargs:
@@ -183,12 +172,9 @@ class _ModuleConnection(object):
         except ValueError as exc:  # HTTP GET request with body
             CORE.warn('Reaching module failed: %s' % (exc,))
             raise BadRequest(str(exc))
-        except concurrent.futures.CancelledError as exc:
+        except asyncio.exceptions.CancelledError as exc:
             CORE.warn('Aborted module process request: %s' % (exc,))
             raise CouldNotConnect(exc)
-        # except asyncio.exceptions.CancelledError as exc:
-        #    CORE.warn('Aborted module process request: %s' % (exc,))
-        #    raise CouldNotConnect(exc)
 
         return response
 
@@ -209,13 +195,7 @@ class ModuleProcess(_ModuleConnection):
         super(ModuleProcess, self).__init__()
         self.name = module
         self.socket = '%s.socket' % (('/run/univention-management-console/%u-%s-%lu-%s' % (os.getpid(), module.replace('/', ''), int(time.time() * 1000), uuid.uuid4()))[:85],)
-        modxmllist = moduleManager[module]
-        python = '/usr/bin/python3' if any(modxml.python_version == 3 for modxml in modxmllist) else '/usr/bin/python2.7'
-        args = [python, MODULE_COMMAND, '-m', module, '-s', self.socket, '-d', str(debug)]
-        for modxml in modxmllist:
-            if modxml.notifier:
-                args.extend(['-n', modxml.notifier])
-                break
+        args = ['/usr/bin/python3', MODULE_COMMAND, '-m', module, '-s', self.socket, '-d', str(debug)]
         if locale:
             args.extend(('-l', '%s' % locale))
         if no_daemonize_module_processes:
@@ -296,8 +276,6 @@ class ModuleProcess(_ModuleConnection):
         # type: (int) -> None
         pid = self.pid()
         CORE.process('ModuleProcess: child %d (%s) exited with %d%s' % (pid, self.name, returncode, self.str_returncode(returncode)))
-        if self._client and not self._client._closed:
-            self._client.close()
         self.disconnect_inactivity_timer()
 
     def str_returncode(self, returncode):
@@ -748,10 +726,8 @@ class Command(Resource):
             # send first command
             self.future = process.request(self.request.method, self.request.full_url(), body=self.request.body or None, headers=headers)
             response = await self.future
-        except concurrent.futures.CancelledError:
+        except asyncio.exceptions.CancelledError:
             raise BadGateway('%s: %s: canceled' % (self._('Connection to module process failed'), module_name))
-        # except asyncio.exceptions.CancelledError:
-        #    raise BadGateway('%s: %s: canceled' % (self._('Connection to module process failed'), module_name))
         except CouldNotConnect as exc:
             # (happens during starting the service and subprocesses when the UNIX sockets aren't available yet)
             # also happens when module process gets killed during request
@@ -869,7 +845,7 @@ class Meta(Resource):
         try:
             with open(self.META_JSON_PATH) as fd:
                 meta_data = json.load(fd)
-        except (EnvironmentError, ValueError) as exc:
+        except (OSError, ValueError) as exc:
             CORE.error('meta.json is not available: %s' % (exc,))
             meta_data = {}
 
@@ -902,7 +878,7 @@ class Info(Resource):
         try:
             with gzip.open('/usr/share/doc/univention-management-console-server/changelog.Debian.gz') as fd:
                 line = fd.readline().decode('utf-8', 'replace')
-        except IOError:
+        except OSError:
             return
         try:
             return self.CHANGELOG_VERSION.match(line).groups()[0]
@@ -1092,12 +1068,12 @@ class SetUserPreferences(UserPreferences):
         # validity / sanitizing
         new_preferences = []
         for key, value in preferences.items():
-            if not isinstance(key, six.string_types):
+            if not isinstance(key, str):
                 CORE.warn('user preferences keys needs to be strings: %r' % (key,))
                 continue
 
             # we can put strings directly into the dict
-            if isinstance(value, six.string_types):
+            if isinstance(value, str):
                 new_preferences.append((key, value))
             else:
                 new_preferences.append((key, json.dumps(value)))
