@@ -38,8 +38,8 @@ import sys
 import time
 import traceback
 import zlib
+from urllib.parse import urlparse, urlunsplit
 
-import six
 from saml2 import BINDING_HTTP_ARTIFACT, BINDING_HTTP_POST, BINDING_HTTP_REDIRECT
 from saml2.client import Saml2Client
 from saml2.ident import code as encode_name_id, decode as decode_name_id
@@ -47,7 +47,6 @@ from saml2.metadata import create_metadata_string
 from saml2.response import StatusError, UnsolicitedResponse, VerificationError
 from saml2.s_utils import UnknownPrincipal, UnsupportedBinding
 from saml2.sigver import MissingKey, SignatureError
-from six.moves.urllib_parse import urlparse, urlunsplit
 from tornado.web import HTTPError
 
 from univention.lib.i18n import NullTranslation
@@ -120,7 +119,7 @@ class SamlError(HTTPError):
             return self.missing_key(exc)
         if isinstance(exc, SignatureError):
             return self.signature_error(exc)
-        six.reraise(etype, exc, etraceback)
+        raise exc.with_traceback(etraceback)
 
     @error
     def unknown_principal(self, exc):
