@@ -31,7 +31,6 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import, division
 
 import io
 import json
@@ -200,12 +199,12 @@ class Server(object):
             return  # we are the child process
         try:
             children = list(shared_memory.children.items())
-        except EnvironmentError:
+        except OSError:
             children = []
         for _child, pid in children:
             try:
                 os.kill(pid, signal)
-            except EnvironmentError as exc:
+            except OSError as exc:
                 CORE.process('Failed sending signal %d to process %d: %s' % (signal, pid, exc))
 
     def run(self):
