@@ -237,11 +237,11 @@ class Session(object):
         else:
             return None
 
-    def logout(self, reload=True):
+    def logout(self):
         CORE.info('User %r logged out' % (self.user.username,))
 
         self.on_logout()
-        self.expire(self.session_id, reload=reload)
+        self.expire(self.session_id)
 
     def _session_timeout_timer(self):
         if self._active_requests:
@@ -289,7 +289,6 @@ class Session(object):
 
     def on_logout(self):
         self.disconnect_timer()
-
         if self.saml:
             self.saml.on_logout()
 
@@ -406,7 +405,7 @@ class Processes(object):
             CORE.info('Starting new module process %s' % (module_name,))
             try:
                 mod_proc = ModuleProcess(module_name, debug=MODULE_DEBUG_LEVEL, locale=accepted_language, no_daemonize_module_processes=no_daemonize_module_processes)
-            except EnvironmentError as exc:
+            except OSError as exc:
                 _ = self.session()._
                 message = _('Could not open the module. %s Please try again later.') % {
                     errno.ENOMEM: _('There is not enough memory available on the server.'),
